"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.sdJwtFromCompact = void 0;
const fromString_1 = require("../disclosures/fromString");
const jwt_1 = require("../jwt");
const keyBinding_1 = require("../keyBinding");
const sdJwtFromCompact = (compact) => {
    const [jwtWithoutDisclosures, ...encodedDisclosures] = compact.split('~');
    const { header, payload, signature } = (0, jwt_1.jwtFromCompact)(jwtWithoutDisclosures);
    if (encodedDisclosures.length === 0) {
        return {
            header,
            payload,
            signature
        };
    }
    const hasKeyBinding = !compact.endsWith('~');
    // If the disclosure array ends with an `~` we do not have
    // a key binding and `String.split` takes it as an empty string
    // as element which we would not like to include in the disclosures.
    if (!hasKeyBinding)
        encodedDisclosures.pop();
    const compactKeyBinding = hasKeyBinding
        ? encodedDisclosures.pop()
        : undefined;
    const keyBinding = compactKeyBinding
        ? (0, keyBinding_1.keyBindingFromCompact)(compactKeyBinding)
        : undefined;
    const disclosures = encodedDisclosures.map(fromString_1.disclosureFromString);
    return {
        header,
        payload,
        signature,
        keyBinding,
        disclosures
    };
};
exports.sdJwtFromCompact = sdJwtFromCompact;
//# sourceMappingURL=fromCompact.js.map